@@ -15,6 +15,9 @@
 This module is used for Pyramid integration
 """
 
+from pyams_table.selector import TableContextSelector, TableRowContextSelector
+
+
 __docformat__ = 'restructuredtext'
 
 
@@ -24,4 +27,8 @@ def include_package(config):
     # add translations
     config.add_translation_dirs('pyams_table:locales')
 
+    # add custom subscriber predicates
+    config.add_subscriber_predicate('table_context_selector', TableContextSelector)
+    config.add_subscriber_predicate('row_context_selector', TableRowContextSelector)
+
     config.scan()
