@@ -16,7 +16,8 @@ This module provides all package interfaces.
 """
 
 from zope.contentprovider.interfaces import IContentProvider
-from zope.interface import Attribute, Interface
+from zope.interface import Attribute, Interface, implementer
+from zope.interface.interfaces import IObjectEvent, ObjectEvent
 from zope.schema import BytesLine, Int, List, TextLine
 
 
@@ -253,3 +254,35 @@ class IColumnHeader(Interface):
 
         The initial use case here is to maintain a search term.
         """
+
+
+class ITableUpdatedEvent(IObjectEvent):
+    """Table update event interface"""
+
+    context = Attribute("Table context object")
+
+
+class ITableRowUpdatedEvent(IObjectEvent):
+    """Table row update event interface"""
+
+    context = Attribute("Table context object")
+    item = Attribute("Table row context object")
+
+
+@implementer(ITableUpdatedEvent)
+class TableUpdatedEvent(ObjectEvent):
+    """Table update event"""
+
+    def __init__(self, obj):
+        super().__init__(obj)
+        self.context = obj.context
+
+
+@implementer(ITableRowUpdatedEvent)
+class TableRowUpdatedEvent(ObjectEvent):
+    """Table row update event"""
+
+    def __init__(self, obj, item):
+        super().__init__(obj)
+        self.context = obj.context
+        self.item = item
