@@ -31,17 +31,19 @@ class ValuesMixin(ContextRequestViewAdapter):
     """Mixin for different value adapters"""
 
 
-@adapter_config(required=(IContainer, IRequest, ITable), provides=IValues)
+@adapter_config(required=(IContainer, IRequest, ITable),
+                provides=IValues)
 class ValuesForContainer(ValuesMixin):
     """Values adapter from a simple IContainer"""
 
     @property
     def values(self):
         """Get container values"""
-        return self.context.values()
+        yield from self.context.values()
 
 
-@adapter_config(required=(Interface, IRequest, ISequenceTable), provides=IValues)
+@adapter_config(required=(Interface, IRequest, ISequenceTable),
+                provides=IValues)
 class ValuesForSequence(ValuesMixin):
     """Values adapter from a simple sequence table"""
 
